"""Библиотека Yandex 360 API

.. moduleauthor:: Купцов Игорь Валерьевич <ya360@uh.net.ru>

"""

try:
    from ._version import __version__
except:
    __version__ = 'dev'

__author__ = 'Купцов Игорь Валерьевич'
